@@ -7,13 +7,13 @@ using namespace std;
 // setting it up
 void RVector::set( double *p_data, int *p_dimData )
 {
-  this->data = p_data;
+  this->ddata = p_data;
   this->I = *p_dimData;
 }
 
 void RVector::set( double *p_data, int p_dimData )
 {
-  this->data = p_data;
+  this->ddata = p_data;
   this->I = p_dimData;
 }
 // accessor function
@@ -25,7 +25,7 @@ double& RVector::operator () (unsigned i)
     Rprintf("Index (%d) is out of range (%d).\n", i, I);
   }
 #endif
-  return( data[i] );
+  return( ddata[i] );
 }
 
 // repeated code from above
@@ -37,5 +37,5 @@ double& RVector::elt( unsigned i )
     Rprintf("Index (%d) is out of range (%d).\n", i, I);
   }
 #endif
-  return( data[i] );
+  return( ddata[i] );
 }
